uniform float time;         // bazik preset playback time in seconds
uniform vec2 resolution;    // bazik render width (x) & height (y)

uniform vec3 color1;        // bazik user color 1 (r=x, g=y, b=z)
uniform vec3 color2;        // bazik user color 2 (r=x, g=y, b=z)
uniform vec3 color3;        // bazik user color 3 (r=x, g=y, b=z)
uniform vec3 color4;        // bazik user color 4 (r=x, g=y, b=z)

uniform float eq1;          // bazik 3 band equalizer bass value 0.0 to 1.0
uniform float eq2;          // bazik 3 band equalizer medium value 0.0 to 1.0
uniform float eq3;          // bazik 3 band equalizer high value 0.0 to 1.0
uniform float banger;       // bazik music banger (beat detect) 0.0 to 1.0

uniform int breaker;        // bazik user control 0 or 1
uniform int mode;           // bazik old user control 1,2,3,4,5,6,7 or 8
uniform float shift;        // bazik user shift random value 0.0 to 1.0

uniform float par1;         // bazik user control -1.0 to 1.0
uniform float par2;         // bazik user control -1.0 to 1.0


vec2 rot(vec2 p, float a)
{
	return vec2(cos(a) * p.x - sin(a) * p.y, sin(a) * p.x + cos(a) * p.y);
}

vec3 tex(vec2 uv)
{
	vec3 c = color1 + vec3(0.5,0.5,0.5);
    //if(mod(uv.x * 2.0, 2.0) > 1.0) return color3;

	if(mod(uv.x * 2.0, 2.0) < 0.9) return vec3(0);
	if(mod(uv.y * 1.0, 1.0) < 0.9) return vec3(0);
	return c;
}

void main(void) {

	float M   = time * 0.2;
    
    if(breaker == 1) M = time * 0.2 + (eq1 * 0.2);
	float fog = 1.0;
	vec2 uv   = 2.0 * ( gl_FragCoord.xy / resolution.xy ) - 1.0;
	vec3  c   = vec3(0);
	for(int i = 0 ; i < int(2.0 + shift * 20.0); i++) {
		c = tex(vec2(uv.x / abs(uv.y / (float(i) + 1.0)) + M + par1 * 0.015, abs(uv.y)));
        
        if(i == 1 && length(c) > 0.5) c = color2;
        if(i == 3 && length(c) > 0.5) c = color3;
		if(length(c) > 0.5) break;
		uv   = uv.yx * (1.1 + (par2 * 0.25));
        uv.y -= M * 1.0 + shift * 4.0;
        uv.x += M * 1.0 + par1;
		fog *= 0.9;
	}
	gl_FragColor = (vec4(c.xyzx * (fog * fog)));
}
